@@ -5,6 +5,7 @@ Tests common to psycopg.AsyncCursor and its subclasses.
 import weakref
 import datetime as dt
 from typing import Any
+from contextlib import aclosing
 
 import pytest
 from packaging.version import parse as ver
@@ -14,12 +15,15 @@ from psycopg import pq, rows, sql
 from psycopg.adapt import PyFormat
 from psycopg.types import TypeInfo
 
+from . import _test_cursor
 from .utils import raiseif
-from .acompat import aclosing, alist, anext
+from .acompat import alist, gather, spawn
 from .fix_crdb import crdb_encoding
-from ._test_cursor import _execmany, execmany, my_row_factory, ph  # noqa: F401
+from .test_adapt import make_loader
+from ._test_cursor import my_row_factory, ph
 
-execmany = execmany  # avoid F811 underneath
+execmany = _test_cursor.execmany  # avoid F811 underneath
+_execmany = _test_cursor._execmany  # needed by the execmany fixture
 
 
 cursor_classes = [psycopg.AsyncCursor, psycopg.AsyncClientCursor]
@@ -158,6 +162,14 @@ async def test_execute_sql(aconn):
     assert (await cur.fetchone()) == ("hello",)
 
 
+async def test_next(aconn):
+    cur = aconn.cursor()
+    await cur.execute("select 1")
+    assert await anext(cur) == (1,)
+    with pytest.raises(StopAsyncIteration):
+        await anext(cur)
+
+
 async def test_query_parse_cache_size(aconn):
     cur = aconn.cursor()
     cls = type(cur)
@@ -211,6 +223,28 @@ async def test_execute_many_results(aconn):
     assert cur.nextset() is None
 
 
+async def test_set_results(aconn):
+    cur = aconn.cursor()
+
+    with pytest.raises(IndexError):
+        await cur.set_result(0)
+
+    await cur.execute("select 'foo'; select generate_series(1,3)")
+    assert await cur.set_result(0) is cur
+    assert (await cur.fetchall()) == [("foo",)]
+    assert cur.rowcount == 1
+
+    assert await cur.set_result(-1) is cur
+    assert (await cur.fetchall()) == [(1,), (2,), (3,)]
+    assert cur.rowcount == 3
+
+    with pytest.raises(IndexError):
+        await cur.set_result(2)
+
+    with pytest.raises(IndexError):
+        await cur.set_result(-3)
+
+
 async def test_execute_sequence(aconn):
     cur = aconn.cursor()
     rv = await cur.execute(
@@ -453,6 +487,22 @@ async def test_executemany_null_first(aconn, fmt_in):
         )
 
 
+@pytest.mark.slow
+async def test_executemany_lock(aconn):
+    async def do_execmany():
+        async with aconn.cursor() as cur:
+            await cur.executemany(
+                ph(cur, "select pg_sleep(%s)"), [(0.1,) for _ in range(10)]
+            )
+
+    async def do_exec():
+        async with aconn.cursor() as cur:
+            for i in range(100):
+                await cur.execute("select 1")
+
+    await gather(spawn(do_execmany), spawn(do_exec))
+
+
 async def test_rowcount(aconn):
     cur = aconn.cursor()
 
@@ -872,3 +922,96 @@ async def test_message_0x33(aconn):
 async def test_typeinfo(aconn):
     info = await TypeInfo.fetch(aconn, "jsonb")
     assert info is not None
+
+
+async def test_error_no_result(aconn):
+    cur = aconn.cursor()
+    with pytest.raises(psycopg.ProgrammingError, match="no result available"):
+        await cur.fetchone()
+
+    await cur.execute("set timezone to utc")
+    with pytest.raises(
+        psycopg.ProgrammingError, match="last operation.*command status: SET"
+    ):
+        await cur.fetchone()
+
+    await cur.execute("")
+    with pytest.raises(
+        psycopg.ProgrammingError, match="last operation.*result status: EMPTY_QUERY"
+    ):
+        await cur.fetchone()
+
+
+async def test_row_maker_returns_none(aconn):
+    cur = aconn.cursor(row_factory=rows.scalar_row)
+    query = "values (null), (0)"
+    recs = [None, 0]
+
+    await cur.execute(query)
+    assert [await cur.fetchone() for _ in range(len(recs))] == recs
+    await cur.execute(query)
+    assert await cur.fetchmany(len(recs)) == recs
+    await cur.execute(query)
+    assert await cur.fetchall() == recs
+    await cur.execute(query)
+    assert await alist(cur) == recs
+    stream = cur.stream(query)
+    assert await alist(stream) == recs
+
+
+@pytest.mark.parametrize("count", [1, 3])
+async def test_results_after_execute(aconn, count):
+    async with aconn.cursor() as cur:
+        await cur.execute(
+            ";".join(f"select * from generate_series(1, {i})" for i in range(count))
+        )
+        ress = await alist(await res.fetchall() async for res in cur.results())
+        assert ress == [[(j + 1,) for j in range(i)] for i in range(count)]
+
+
+@pytest.mark.parametrize("count", [0, 1, 3])
+@pytest.mark.parametrize("returning", [False, True])
+async def test_results_after_executemany(aconn, count, returning):
+    async with aconn.cursor() as cur:
+        await cur.executemany(
+            ph(cur, "select * from generate_series(1, %s)"),
+            [(i,) for i in range(count)],
+            returning=returning,
+        )
+        ress = await alist(await res.fetchall() async for res in cur.results())
+        if returning:
+            assert ress == [[(j + 1,) for j in range(i)] for i in range(count)]
+        else:
+            assert ress == []
+
+
+async def test_change_loader_results(aconn):
+    cur = aconn.cursor()
+    # With no result
+    cur.adapters.register_loader("text", make_loader("1"))
+
+    await cur.execute(
+        """
+        values ('foo'::text);
+        values ('bar'::text), ('baz');
+        values ('qux'::text);
+        """
+    )
+    assert (await cur.fetchall()) == [("foo1",)]
+
+    cur.nextset()
+    assert (await cur.fetchone()) == ("bar1",)
+    cur.adapters.register_loader("text", make_loader("2"))
+    assert (await cur.fetchone()) == ("baz2",)
+    await cur.scroll(-2)
+    assert (await cur.fetchall()) == [("bar2",), ("baz2",)]
+
+    cur.nextset()
+    assert (await cur.fetchall()) == [("qux2",)]
+
+    # After the final result
+    assert not cur.nextset()
+    cur.adapters.register_loader("text", make_loader("3"))
+    assert (await cur.fetchone()) is None
+    await cur.set_result(0)
+    assert (await cur.fetchall()) == [("foo3",)]
